searchData={"content_type":"text/markdown","items":[{"doc":"InfluxDB writer for Elixir that uses InfluxDB's line protocol over UDP.\n\nTo get started with Fluxter, you have to create a module that calls `use\nFluxter`, like this:\n\n    defmodule MyApp.Fluxter do\n      use Fluxter\n    end\n\nThis way, `MyApp.Fluxter` becomes an InfluxDB connection pool. Each Fluxter\npool provides a `c:start_link/1` function that starts that pool and connects to\nInfluxDB; this function needs to be invoked before being able to send data to\nInfluxDB. Typically, you won't call `start_link/1` directly as you'll want to\nadd Fluxter pools to your application's supervision tree:\n\n    def start(_type, _args) do\n      children = [\n        MyApp.Fluxter,\n        # ...\n      ]\n      Supervisor.start_link(children, strategy: :one_for_one)\n    end\n\nOnce a Fluxter pool is started, its `c:write/2,3`, `c:measure/2,3,4`, and other\nfunctions can successfully be used to send points to the data store.\nA Fluxter pool implements the `Fluxter` behaviour, so you can read documentation\nfor the callbacks the behaviour provides to know more about these functions.","ref":"Fluxter.html","title":"Fluxter","type":"behaviour"},{"doc":"Fluxter can be configured either globally or on a per-pool basis.\n\nThe global configuration will affect all Fluxter pools; it can be specified by\nconfiguring the `:fluxter` application:\n\n    config :fluxter,\n      host: \"metrics.example.com\",\n      port: 1122\n\nThe per-pool configuration can be specified by configuring the pool module\nunder the `:fluxter` application:\n\n    config :fluxter, MyApp.Fluxter,\n      host: \"metrics.example.com\",\n      port: 1122,\n      pool_size: 10\n\nThe following is a list of all the supported options:\n\n  * `:host` - (binary) the host to send metrics to. Defaults to `\"127.0.0.1\"`.\n  * `:port` - (integer) the port (on `:host`) to send the metrics to. Defaults\n    to `8092`.\n  * `:prefix` - (binary or `nil`) all metrics sent to the data store through\n    the configured Fluxter pool will be prefixed by the value of this\n    option. If `nil`, metrics will not be prefixed. Defaults to `nil`.\n  * `:pool_size` - (integer) the size of the connection pool for the given\n    Fluxter pool. **This option can only be configured on a per-pool basis**;\n    configuring it globally for the `:fluxter` application has no\n    effect. Defaults to `5`.","ref":"Fluxter.html#module-configuration","title":"Configuration - Fluxter","type":"behaviour"},{"doc":"Fluxter supports counters: a counter is a metric aggregator designed to\nlocally aggregate a numeric value and flush the aggregated value only once to\nthe storage, as a single metric. This is very useful when you have the need to\nwrite a high number of metrics in a very short amount of time. Doing so can\nhave a negative impact on the speed of your code and can also cause network\npacket drops.\n\nFor example, code like the following:\n\n    for value <- 1..1_000_000 do\n      my_operation(value)\n      MyApp.Fluxter.write(\"my_operation_success\", [host: \"eu-west\"], 1)\n    end\n\ncan take advantage of metric aggregation:\n\n    counter = MyApp.Fluxter.start_counter(\"my_operation_success\", [host: \"eu-west\"])\n    for value <- 1..1_000_000 do\n      my_operation(value)\n      MyApp.Fluxter.increment_counter(counter, 1)\n    end\n    MyApp.Fluxter.flush_counter(counter)","ref":"Fluxter.html#module-metric-aggregation","title":"Metric aggregation - Fluxter","type":"behaviour"},{"doc":"Returns a child specification for this Fluxter pool.\n\nThis is usually used to supervise this Fluxter pool under the supervision tree\nof your application:\n\n    def start(_type, _args) do\n      children = [\n        MyApp.Fluxter,\n        # ...\n      ]\n      Supervisor.start_link(children, strategy: :one_for_one)\n    end\n\n`options` is a list of options that will be given to `c:start_link/1`.","ref":"Fluxter.html#c:child_spec/1","title":"Fluxter.child_spec/1","type":"callback"},{"doc":"","ref":"Fluxter.html#t:counter/0","title":"Fluxter.counter/0","type":"opaque"},{"doc":"","ref":"Fluxter.html#t:field_value/0","title":"Fluxter.field_value/0","type":"type"},{"doc":"","ref":"Fluxter.html#t:fields/0","title":"Fluxter.fields/0","type":"type"},{"doc":"Flushes the given `counter` by writing its aggregated value as a single metric.\n\nThis function performs a *fire-and-forget* operation (a cast) on the given\ncounter, hence it will always return `:ok`.\n\nThis function will also stop the `counter` process after the metric is flushed.\n\nSee the \"Metric aggregation\" section in the documentation for `Fluxter` for more\ninformation on counters.","ref":"Fluxter.html#c:flush_counter/1","title":"Fluxter.flush_counter/1","type":"callback"},{"doc":"Assuming a `MyApp.Fluxter` Fluxter pool exists:\n\n    iex> MyApp.Fluxter.flush_counter(counter)\n    :ok","ref":"Fluxter.html#c:flush_counter/1-examples","title":"Examples - Fluxter.flush_counter/1","type":"callback"},{"doc":"Adds the `extra` value to the given `counter`.\n\nThis function adds the `extra` value (a number) to the current value of the\ngiven `counter`. To subtract, just use a negative number to add to the current\nvalue of `counter`.\n\nThis function performs a *fire-and-forget* operation (a cast) on the given\ncounter, hence it will always return `:ok`.\n\nSee the \"Metric aggregation\" section in the documentation for `Fluxter` for more\ninformation on counters.","ref":"Fluxter.html#c:increment_counter/2","title":"Fluxter.increment_counter/2","type":"callback"},{"doc":"Assuming a `MyApp.Fluxter` Fluxter pool exists:\n\n    iex> MyApp.Fluxter.increment_counter(counter, 1)\n    :ok","ref":"Fluxter.html#c:increment_counter/2-examples","title":"Examples - Fluxter.increment_counter/2","type":"callback"},{"doc":"Should be the same as `measure(measurement, [], [], fun_or_mfa)`.","ref":"Fluxter.html#c:measure/2","title":"Fluxter.measure/2","type":"callback"},{"doc":"Should be the same as `measure(measurement, tags, [], fun_or_mfa)`.","ref":"Fluxter.html#c:measure/3","title":"Fluxter.measure/3","type":"callback"},{"doc":"Measures the execution time of `fun_or_mfa` and writes it as a metric.\n\nThis function is just an utility function to measure the execution time of a\ngiven function `fun_or_mfa`. The `measurement` and `tags` arguments work in the same way as\nin `c:write/3`.\n\n`fun_or_mfa`'s execution time is prepended as a field called `value` to the already\nexisting list of `fields`. This means that if there's already a field called\n`value` in `fields`, it will be overridden by the measurement. This also means\nthat `fields` must be a list of key-value pairs (field name and value): simple\nfloats, integers, booleans, and binaries as values for `fields` are not\nsupported like they are in `c:write/3`.\n\nThis function returns whatever `fun` returns.","ref":"Fluxter.html#c:measure/4","title":"Fluxter.measure/4","type":"callback"},{"doc":"Assuming a `MyApp.Fluxter` Fluxter pool exists:\n\n    iex> MyApp.Fluxter.measure \"task_exec_time\", [host: \"us-east\"], fn ->\n    ...>   1 + 1\n    ...> end\n    2","ref":"Fluxter.html#c:measure/4-examples","title":"Examples - Fluxter.measure/4","type":"callback"},{"doc":"","ref":"Fluxter.html#t:measurement/0","title":"Fluxter.measurement/0","type":"type"},{"doc":"Should be the same as `start_counter(measurement, [], [])`.","ref":"Fluxter.html#c:start_counter/1","title":"Fluxter.start_counter/1","type":"callback"},{"doc":"Should be the same as `start_counter(measurement, tags, [])`.","ref":"Fluxter.html#c:start_counter/2","title":"Fluxter.start_counter/2","type":"callback"},{"doc":"Starts a counter for a metric.\n\nThe purpose of this counter is to aggregate a numeric metric: values aggregated\nin the counter will only be written to the storage as a single metric when the\ncounter is \"flushed\" (see `c:flush_counter/1`). `tags` and `fields` will be tags\nand fields attached to the metric when it's flushed. The aggregated value of\nthe metric will be prepended to `fields` as a field called `value`; this means\nthat if there's already a field called `value` in `fields`, it will be\noverridden.\n\nThis function spawns a process that is linked to the caller process.\nThe linking part is important because it means that if the parent process dies,\nthe counter will be terminated as well and its aggregated metric will be lost.\n\nSee the \"Metric aggregation\" section in the documentation for `Fluxter` for more\ninformation on counters.","ref":"Fluxter.html#c:start_counter/3","title":"Fluxter.start_counter/3","type":"callback"},{"doc":"Assuming a `MyApp.Fluxter` Fluxter pool exists:\n\n    iex> MyApp.Fluxter.start_counter(\"hits\", [host: \"us-west\"])\n    {:ok, #PID<...>}","ref":"Fluxter.html#c:start_counter/3-examples","title":"Examples - Fluxter.start_counter/3","type":"callback"},{"doc":"Should be the same as `start_link([])`.","ref":"Fluxter.html#c:start_link/0","title":"Fluxter.start_link/0","type":"callback"},{"doc":"Starts this Fluxter pool.\n\nA Fluxter pool is a set of processes supervised by a supervisor; this function\nstarts all those processes and that supervisor.\n\nThe following options are supported: `:host`, `:port`, and `:prefix`.\n\nIf you plan on having a Fluxter pool started under your application's\nsupervision tree, use `c:child_spec/1`.","ref":"Fluxter.html#c:start_link/1","title":"Fluxter.start_link/1","type":"callback"},{"doc":"","ref":"Fluxter.html#t:tags/0","title":"Fluxter.tags/0","type":"type"},{"doc":"Should be the same as `write(measurement, [], fields)`.","ref":"Fluxter.html#c:write/2","title":"Fluxter.write/2","type":"callback"},{"doc":"Writes a metric to the data store.\n\n`measurement` is the name of the metric to write.\n`tags` is a list of key-value pairs that specifies tags (as name and value)\nfor the data point to write; note that tag values are converted to strings\nas InfluxDB only support string values for tags.\n`fields` can either be a list of key-value pairs, in which case it\nspecifies a list of fields (as name and value), or a single value\n(specifically, a boolean, float, integer, or binary). In the latter case, the\ndefault field name of `value` will be used: calling `write(\"foo\", [], 4.3)` is\nthe same as calling `write(\"foo\", [], value: 4.3)`.\n\nThe return value is always `:ok` as writing is a *fire-and-forget* operation.","ref":"Fluxter.html#c:write/3","title":"Fluxter.write/3","type":"callback"},{"doc":"Assuming a `MyApp.Fluxter` Fluxter pool exists:\n\n    iex> MyApp.Fluxter.write(\"cpu_temp\", [host: \"eu-west\"], 68)\n    :ok","ref":"Fluxter.html#c:write/3-examples","title":"Examples - Fluxter.write/3","type":"callback"},{"doc":"# Fluxter\n\n![CI Status](https://github.com/lexmag/fluxter/workflows/CI/badge.svg)\n[![Hex Version](https://img.shields.io/hexpm/v/fluxter.svg \"Hex Version\")](https://hex.pm/packages/fluxter)\n\nFluxter is an [InfluxDB](https://www.influxdata.com/) writer for Elixir. It uses the InfluxDB line protocol over UDP.","ref":"readme.html","title":"Fluxter","type":"extras"},{"doc":"Add Fluxter as a dependency to your `mix.exs` file:\n\n```elixir\ndefp deps() do\n  [{:fluxter, \"~> 0.11\"}]\nend\n```\n\nThen run `mix deps.get` in your shell to fetch the dependencies.","ref":"readme.html#installation","title":"Installation - Fluxter","type":"extras"},{"doc":"See [the documentation](https://hexdocs.pm/fluxter) for detailed usage information.\n\nA module that uses Fluxter becomes an InfluxDB connection pool:\n\n```elixir\ndefmodule MyApp.Fluxter do\n  use Fluxter\nend\n```\n\nEach Fluxter pool provides a `start_link/1` function that starts the pool and connects to InfluxDB; this function needs to be invoked before the pool can be used.\nTypically, you won't call `start_link/1` directly as you'll want to\nadd a Fluxter pool to your application's supervision tree.\nFor this use case, pools provide a `child_spec/1` function:\n\n```elixir\ndef start(_type, _args) do\n  children = [\n    MyApp.Fluxter,\n    #...\n  ]\n  Supervisor.start_link(children, strategy: :one_for_one)\nend\n```\n\nOnce the Fluxter pool is started, its `write/2,3`, `measure/2,3,4`, and other functions can successfully be used to send points to the data store.","ref":"readme.html#usage","title":"Usage - Fluxter","type":"extras"},{"doc":"This software is licensed under [the ISC license](LICENSE).","ref":"readme.html#license","title":"License - Fluxter","type":"extras"},{"doc":"# Changelog","ref":"changelog.html","title":"Changelog","type":"extras"},{"doc":"* Dropped support for Elixir versions older than 1.14.","ref":"changelog.html#v0-11-0","title":"v0.11.0 - Changelog","type":"extras"},{"doc":"* Dropped support for Elixir versions older than 1.5.","ref":"changelog.html#v0-10-0","title":"v0.10.0 - Changelog","type":"extras"},{"doc":"* Fixed the order when building prefix.","ref":"changelog.html#v0-9-1","title":"v0.9.1 - Changelog","type":"extras"},{"doc":"* Fixed prefix building when start options provided.\n  * Dropped support for Elixir v1.2.","ref":"changelog.html#v0-9-0","title":"v0.9.0 - Changelog","type":"extras"},{"doc":"* Fixed port command for OTP versions that support ancillary data sending.","ref":"changelog.html#v0-8-1","title":"v0.8.1 - Changelog","type":"extras"},{"doc":"* Added support for module, function, arguments tuple in `measure/4`.","ref":"changelog.html#v0-8-0","title":"v0.8.0 - Changelog","type":"extras"},{"doc":"* Fixed Elixir v1.6 warnings.","ref":"changelog.html#v0-7-1","title":"v0.7.1 - Changelog","type":"extras"},{"doc":"* Added the `c:Fluxter.start_link/1` callback to support runtime configuration.\n\n__Deprecations:__\n\n  * Passing child specification options to `child_spec/1` is deprecated.","ref":"changelog.html#v0-7-0","title":"v0.7.0 - Changelog","type":"extras"},{"doc":"* Fixed a bug in the `c:Fluxter.child_spec/1` callback.","ref":"changelog.html#v0-6-1","title":"v0.6.1 - Changelog","type":"extras"},{"doc":"* Added the `c:Fluxter.child_spec/1` callback.\n  * Started flushing counters synchronously when calling `Fluxter.flush_counter/1`.","ref":"changelog.html#v0-6-0","title":"v0.6.0 - Changelog","type":"extras"}],"producer":{"name":"ex_doc","version":"0.38.1"},"proglang":"elixir"}